@@ -37,6 +37,16 @@ class AbstractModel(abc.ABC):
         """Create hash from ``_key``."""
         return hash(self._key)
 
+    def update(self, data: dict[str, Any]) -> "AbstractModel":
+        """Update the model with given values."""
+        return self._update(data)
+
+    def _update(self, data: dict[str, Any]) -> "AbstractModel":
+        current = self.to_dict()
+        filtered = {key: data[key] for key, value in data.items() if key in current}
+        updated = current | filtered
+        return self.__class__(**updated)
+
     def to_dict(self) -> dict[str, Any]:
         """Convert to dictionary."""
         return dataclasses.asdict(self)
