@@ -1,4 +1,5 @@
 from . import postgresql
 from .database import AbstractClient
 from .repository import AbstractRepository
-from .repository import NotFoundInDatabaseError
+from .repository import NotFoundInDatabaseException
+from .repository import ReferenceViolationException
