@@ -12,7 +12,7 @@ class FakeModel(model.AbstractModel):
 
     @property
     def _key(self) -> Union[Any, tuple[Any]]:
-        return self.id
+        return (self.id, self.test_key)
 
     @property
     def identifier(self) -> dict[str, Any]:
