@@ -1,17 +1,18 @@
+from typing import Any
 from typing import Optional
 
 from cosmics.repository import database
 
 
 class FakeClient(database.AbstractClient):
-    def __init__(self, contains: list[dict]):
+    def __init__(self, contains: dict[str, list[dict[str, Any]]]):
         self.contains = contains
 
-    def __del__(self):
+    def __del__(self, commit: bool = False):
         pass
 
     def _insert(self, target: str, data: database.Info) -> None:
-        self.contains.append(data)
+        self.contains[target].append(data)
 
     def _select(
         self,
@@ -19,8 +20,8 @@ class FakeClient(database.AbstractClient):
         where: Optional[database.Info],
     ) -> list[database.Info]:
         if where is None:
-            return self.contains
-        return [d for d in self.contains if _all_values_match(d, where)]
+            return self.contains[target]
+        return [d for d in self.contains[target] if _all_values_match(d, where)]
 
     def _update(
         self,
@@ -28,13 +29,15 @@ class FakeClient(database.AbstractClient):
         data: database.Info,
         where: database.Info,
     ) -> None:
-        self.contains = [
+        self.contains[target] = [
             d if not _all_values_match(d, where) else _update_dict(d, data)
-            for d in self.contains
+            for d in self.contains[target]
         ]
 
-    def _delete(self, target: str, where: database.Info, force: bool) -> None:
-        self.contains = [d for d in self.contains if not _all_values_match(d, where)]
+    def _delete(self, target: str, where: database.Info) -> None:
+        self.contains[target] = [
+            d for d in self.contains[target] if not _all_values_match(d, where)
+        ]
 
 
 def _all_values_match(left: dict, right: dict) -> bool:
