@@ -4,7 +4,7 @@ from cosmics.testing.fakes.repository import database
 
 
 class FakeRepository(repository.AbstractRepository):
-    _target = "test-target"
+    _target = "test_target"
     _model: model.FakeModel = model.FakeModel
 
     def __init__(self, client: database.FakeClient):
